pub fn parse_inline(src: &str) -> ParsedTextExpand description
Parse inline markdown into styled text.
Never fails and never panics: any construct that doesn’t close renders as the literal characters that were typed.
pub fn parse_inline(src: &str) -> ParsedTextParse inline markdown into styled text.
Never fails and never panics: any construct that doesn’t close renders as the literal characters that were typed.